@@ -1,6 +1,8 @@
 package Mouse::Meta::Method::Accessor;
 use Mouse::Util qw(:meta); # enables strict and warnings
 
+use constant _MOUSE_DEBUG => !!$ENV{MOUSE_DEBUG};
+
 sub _inline_slot{
     my(undef, $self_var, $attr_name) = @_;
     return sprintf '%s->{q{%s}}', $self_var, $attr_name;
@@ -123,7 +125,7 @@ sub _generate_accessor_any{
 
     $accessor .= "return $slot;\n}\n";
 
-    #print $accessor, "\n";
+    warn $accessor if _MOUSE_DEBUG;
     my $code;
     my $e = do{
         local $@;
@@ -182,7 +184,7 @@ Mouse::Meta::Method::Accessor - A Mouse method generator for accessors
 
 =head1 VERSION
 
-This document describes Mouse version 0.73
+This document describes Mouse version 0.74
 
 =head1 SEE ALSO
 
